@@ -152,6 +152,11 @@ bool ChunkManager::isStorageMounted(QStringList &missing)
     return d->cache->isStorageMounted(missing);
 }
 
+void ChunkManager::saveFileMap()
+{
+    return d->cache->saveFileMap();
+}
+
 Chunk *ChunkManager::getChunk(unsigned int i)
 {
     if (i >= (Uint32)d->chunks.size())
@@ -329,7 +334,7 @@ void ChunkManager::prioritise(Uint32 from, Uint32 to, Priority priority)
 
         i++;
     }
-    updateStats();
+    Q_EMIT updateStats();
 }
 
 void ChunkManager::prioritisePreview(Uint32 from, Uint32 to)
@@ -357,7 +362,7 @@ void ChunkManager::prioritisePreview(Uint32 from, Uint32 to)
 
         c->setPriority(priority);
     }
-    updateStats();
+    Q_EMIT updateStats();
 }
 
 void ChunkManager::exclude(Uint32 from, Uint32 to)
@@ -376,8 +381,8 @@ void ChunkManager::exclude(Uint32 from, Uint32 to)
         i++;
     }
     d->recalc_chunks_left = true;
-    excluded(from, to);
-    updateStats();
+    Q_EMIT excluded(from, to);
+    Q_EMIT updateStats();
 }
 
 void ChunkManager::include(Uint32 from, Uint32 to)
@@ -395,8 +400,8 @@ void ChunkManager::include(Uint32 from, Uint32 to)
         i++;
     }
     d->recalc_chunks_left = true;
-    updateStats();
-    included(from, to);
+    Q_EMIT updateStats();
+    Q_EMIT included(from, to);
 }
 
 void ChunkManager::Private::savePriorityInfo()
@@ -526,7 +531,7 @@ void ChunkManager::downloadPriorityChanged(TorrentFile *tf, Priority newpriority
             prioritise(first, first, newpriority);
 
         if (newpriority == ONLY_SEED_PRIORITY)
-            excluded(first, last);
+            Q_EMIT excluded(first, last);
     } else {
         // if the first one is a border chunk use setBorderChunkPriority and make the range smaller
         if (d->isBorderChunk(first)) {
@@ -544,7 +549,7 @@ void ChunkManager::downloadPriorityChanged(TorrentFile *tf, Priority newpriority
         if (first <= last) {
             prioritise(first, last, newpriority);
             if (newpriority == ONLY_SEED_PRIORITY)
-                excluded(first, last);
+                Q_EMIT excluded(first, last);
         }
     }
 
@@ -1053,7 +1058,7 @@ void ChunkManager::Private::setBorderChunkPriority(Uint32 idx, Priority prio)
     }
     p->prioritise(idx, idx, highest);
     if (highest == ONLY_SEED_PRIORITY)
-        p->excluded(idx, idx);
+        Q_EMIT p->excluded(idx, idx);
 }
 
 bool ChunkManager::Private::resetBorderChunk(Uint32 idx, TorrentFile *tf)
