@@ -9,6 +9,7 @@
 
 #include <QDateTime>
 #include <QObject>
+#include <QStringList>
 #include <QTimer>
 #include <QUrl>
 
@@ -19,7 +20,6 @@
 #include <ktorrent_export.h>
 #include <util/timer.h>
 
-class QStringList;
 class QString;
 class KJob;
 
@@ -243,6 +243,8 @@ public:
      * */
     void trackerScrapeDone();
 
+    void afterRename();
+
     /**
      * Enable or disable data check upon completion
      * @param on
